@@ -1,9 +1,4 @@
-from notejob.center.app import db
-
 from .cron_infos import CronInfos
 from .job_log import JobLog
 
 from.job_log_items import JobLogItems
-
-
-# db.create_all()
