@@ -1,5 +1,5 @@
 
-from ...app import db
+from notejob.center.app.core import db
 
 
 class CronInfos(db.Model):
